You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2008/11/25 21:00:24 UTC

svn commit: r720581 - in /activemq/camel/trunk/camel-core/src/main/java/org/apache/camel: builder/ language/bean/ model/ processor/

Author: davsclaus
Date: Tue Nov 25 12:00:24 2008
New Revision: 720581

URL: http://svn.apache.org/viewvc?rev=720581&view=rev
Log:
CAMEL-1087, CAMEL-1116: Added javadoc for fluent builders
CAMEL-1117: Added bean as ValueBuilder on RouteBuilder to allow end users easy to invoke beans for Expressions

Modified:
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/Builder.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/BuilderSupport.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/ExpressionBuilder.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/language/bean/BeanLanguage.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ExceptionType.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/OptionalIdentifiedType.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesType.java
    activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Delayer.java

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/Builder.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/Builder.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/Builder.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/Builder.java Tue Nov 25 12:00:24 2008
@@ -36,6 +36,31 @@
     }
 
     /**
+     * Returns a <a href="http://activemq.apache.org/camel/bean-language.html">bean expression</a>
+     * value builder
+     *
+     * @param beanRef  reference to bean to lookup in the Registry
+     * @return the builder
+     */
+    public static ValueBuilder bean(String beanRef) {
+        Expression expression = ExpressionBuilder.beanExpression(beanRef);
+        return new ValueBuilder(expression);
+    }
+
+    /**
+     * Returns a <a href="http://activemq.apache.org/camel/bean-language.html">bean expression</a>
+     * value builder
+     *
+     * @param beanRef  reference to bean to lookup in the Registry
+     * @param method   name of method to invoke
+     * @return the builder
+     */
+    public static ValueBuilder bean(String beanRef, String method) {
+        Expression expression = ExpressionBuilder.beanExpression(beanRef, method);
+        return new ValueBuilder(expression);
+    }
+
+    /**
      * Returns a constant expression
      */
     public static ValueBuilder constant(Object value) {

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/BuilderSupport.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/BuilderSupport.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/ExpressionBuilder.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/ExpressionBuilder.java Tue Nov 25 12:00:24 2008
@@ -706,18 +706,24 @@
         };
     }
 
-    public static Expression beanExpression(final String bean) {
+    public static Expression beanExpression(final String expression) {
         return new Expression() {
             public Object evaluate(Exchange exchange) {
                 // must call evalute to return the nested langauge evaluate when evaluating
                 // stacked expressions
-                return BeanLanguage.bean(bean).evaluate(exchange);
+                return BeanLanguage.bean(expression).evaluate(exchange);
             }
 
             @Override
             public String toString() {
-                return "bean(" + bean + ")";
+                return "bean(" + expression + ")";
             }
         };
     }
+
+    public static Expression beanExpression(final String beanRef, final String methodName) {
+        String expression = methodName != null ? beanRef + "." + methodName : beanRef;
+        return beanExpression(expression);
+    }
+
 }

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/RouteBuilder.java Tue Nov 25 12:00:24 2008
@@ -94,10 +94,9 @@
     }
 
     /**
-     * Installs the given error handler builder
+     * Installs the given <a href="http://activemq.apache.org/camel/error-handler.html">error handler</a> builder
      *
-     * @param errorHandlerBuilder the error handler to be used by default for
-     *                all child routes
+     * @param errorHandlerBuilder  the error handler to be used by default for all child routes
      * @return the current builder with the error handler configured
      */
     public RouteBuilder errorHandler(ErrorHandlerBuilder errorHandlerBuilder) {
@@ -106,14 +105,14 @@
     }
 
     /**
-     * Configures whether or not the error handler is inherited by every
-     * processing node (or just the top most one)
+     * Configures whether or not the <a href="http://activemq.apache.org/camel/error-handler.html">error handler</a>
+     * is inherited by every processing node (or just the top most one)
      *
-     * @param value the flag as to whether error handlers should be inherited or not
+     * @param inherit  whether error handlers should be inherited or not
      * @return the current builder
      */
-    public RouteBuilder inheritErrorHandler(boolean value) {
-        routeCollection.setInheritErrorHandlerFlag(value);
+    public RouteBuilder inheritErrorHandler(boolean inherit) {
+        routeCollection.setInheritErrorHandlerFlag(inherit);
         return this;
     }
 
@@ -149,19 +148,21 @@
     }
 
     /**
-     * Adds an exception handler route for the given exception type
+     * <a href="http://activemq.apache.org/camel/exception-clause.html">Exception clause</a>
+     * for cathing certain exceptions and handling them.
      *
-     * @param exceptionType  the exception type
+     * @param exception exception to catch
      * @return the builder
      */
-    public ExceptionType onException(Class exceptionType) {
-        return routeCollection.onException(exceptionType);
+    public ExceptionType onException(Class exception) {
+        return routeCollection.onException(exception);
     }
 
     /**
-     * Adds an exception handler route for the given exception types
+     * <a href="http://activemq.apache.org/camel/exception-clause.html">Exception clause</a>
+     * for cathing certain exceptions and handling them.
      *
-     * @param exceptions  list of exceptions types
+     * @param exceptions list of exceptions to catch
      * @return the builder
      */
     public ExceptionType onException(Class... exceptions) {
@@ -260,6 +261,11 @@
         route.setGroup(getClass().getName());
     }
 
+    /**
+     * Adds a collection of routes to this context
+     *
+     * @throws Exception if the routes could not be created for whatever reason
+     */
     protected void addRoutes(Routes routes) throws Exception {
         getContext().addRoutes(routes);
     }

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/language/bean/BeanLanguage.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/language/bean/BeanLanguage.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/language/bean/BeanLanguage.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/language/bean/BeanLanguage.java Tue Nov 25 12:00:24 2008
@@ -43,7 +43,7 @@
     /**
      * Creates the expression based on the string syntax.
      *
-     * @param expression the string syntax
+     * @param expression the string syntax <tt>beanRef.methodName</tt> where methodName can be omitted
      * @return the expression
      */
     public static Expression bean(String expression) {

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ExceptionType.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ExceptionType.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ExceptionType.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ExceptionType.java Tue Nov 25 12:00:24 2008
@@ -85,9 +85,6 @@
         return "Exception[" + getExceptionClasses() + (onWhen != null ? " " + onWhen : "") + " -> " + getOutputs() + "]";
     }
     
-    /**
-     * Catches an exception type.
-     */
     @Override
     public ExceptionType onException(Class exceptionType) {
         getExceptionClasses().add(exceptionType);

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/OptionalIdentifiedType.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/OptionalIdentifiedType.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/OptionalIdentifiedType.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/OptionalIdentifiedType.java Tue Nov 25 12:00:24 2008
@@ -109,6 +109,9 @@
         return (T) this;
     }
 
+    /**
+     * Gets the node id, creating one if not already set.
+     */
     public String idOrCreate() {
         if (id == null) {
             setId(createId());
@@ -120,7 +123,7 @@
     // -------------------------------------------------------------------------
 
     /**
-     * A helper method to create a new ID for this node
+     * A helper method to create a new id for this node
      */
     protected String createId() {
         String key = getShortName();

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java Tue Nov 25 12:00:24 2008
@@ -70,7 +70,6 @@
  */
 @XmlAccessorType(XmlAccessType.PROPERTY)
 public abstract class ProcessorType<Type extends ProcessorType> extends OptionalIdentifiedType<Type> implements Block {
-    public static final String DEFAULT_TRACE_CATEGORY = "org.apache.camel.TRACE";
     private static final transient Log LOG = LogFactory.getLog(ProcessorType.class);
     private ErrorHandlerBuilder errorHandlerBuilder;
     private Boolean inheritErrorHandlerFlag;
@@ -1243,10 +1242,11 @@
     // -------------------------------------------------------------------------
 
     /**
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
      * Adds the custom processor to this destination which could be a final
      * destination, or could be a transformation in a pipeline
      *
-     * @param processor  the custom processor
+     * @param processor  the custom {@link Processor}
      * @return the builder
      */
     public Type process(Processor processor) {
@@ -1256,10 +1256,11 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
      * Adds the custom processor reference to this destination which could be a final
      * destination, or could be a transformation in a pipeline
      *
-     * @param ref   reference to a processor to lookup in the registry
+     * @param ref   reference to a {@link Processor} to lookup in the registry
      * @return the builder
      */
     public Type processRef(String ref) {
@@ -1270,8 +1271,8 @@
     }
 
     /**
-     * Adds a <a href="http://activemq.apache.org/camel/bean-language.html">bean</a>
-     * which is invoked which could be a final destination, or could be a transformation in a pipeline
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
+     * Adds a bean which is invoked which could be a final destination, or could be a transformation in a pipeline
      *
      * @param bean  the bean to invoke
      * @return the builder
@@ -1284,8 +1285,8 @@
     }
 
     /**
-     * Adds a <a href="http://activemq.apache.org/camel/bean-language.html">bean</a>
-     * which is invoked which could be a final destination, or could be a transformation in a pipeline
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
+     * Adds a bean which is invoked which could be a final destination, or could be a transformation in a pipeline
      *
      * @param bean  the bean to invoke
      * @param method  the method name to invoke on the bean (can be used to avoid ambiguty)
@@ -1300,8 +1301,8 @@
     }
 
     /**
-     * Adds a <a href="http://activemq.apache.org/camel/bean-language.html">bean</a>
-     * which is invoked which could be a final destination, or could be a transformation in a pipeline
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
+     * Adds a bean which is invoked which could be a final destination, or could be a transformation in a pipeline
      *
      * @param  beanType  the bean class, Camel will instantiate an object at runtime
      * @return the builder
@@ -1314,8 +1315,8 @@
     }
 
     /**
-     * Adds a <a href="http://activemq.apache.org/camel/bean-language.html">bean</a>
-     * which is invoked which could be a final destination, or could be a transformation in a pipeline
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
+     * Adds a bean which is invoked which could be a final destination, or could be a transformation in a pipeline
      *
      * @param  beanType  the bean class, Camel will instantiate an object at runtime
      * @param method  the method name to invoke on the bean (can be used to avoid ambiguty)
@@ -1330,8 +1331,8 @@
     }
 
     /**
-     * Adds a <a href="http://activemq.apache.org/camel/bean-language.html">bean</a>
-     * which is invoked which could be a final destination, or could be a transformation in a pipeline
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
+     * Adds a bean which is invoked which could be a final destination, or could be a transformation in a pipeline
      *
      * @param ref  reference to a bean to lookup in the registry
      * @return the builder
@@ -1343,8 +1344,8 @@
     }
 
     /**
-     * Adds a <a href="http://activemq.apache.org/camel/bean-language.html">bean</a>
-     * which is invoked which could be a final destination, or could be a transformation in a pipeline
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
+     * Adds a bean which is invoked which could be a final destination, or could be a transformation in a pipeline
      *
      * @param ref  reference to a bean to lookup in the registry
      * @param method  the method name to invoke on the bean (can be used to avoid ambiguty)
@@ -1357,6 +1358,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
      * Adds a processor which sets the body on the IN message
      *
      * @return a expression builder clause to set the body
@@ -1369,6 +1371,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
      * Adds a processor which sets the body on the IN message
      *
      * @param expression   the expression used to set the body
@@ -1381,6 +1384,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
      * Adds a processor which sets the body on the OUT message
      *
      * @param expression   the expression used to set the body
@@ -1393,6 +1397,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/message-translator.html">Message Translator EIP:</a>
      * Adds a processor which sets the body on the OUT message
      *
      * @return a expression builder clause to set the body
@@ -1564,6 +1569,7 @@
     // -------------------------------------------------------------------------
 
     /**
+     * <a href="http://activemq.apache.org/camel/data-format.html">DataFormat:</a>
      * Unmarshals the in body using a {@link DataFormat} expression to define
      * the format of the input message and the output will be set on the out message body.
      *
@@ -1574,6 +1580,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/data-format.html">DataFormat:</a>
      * Unmarshals the in body using the specified {@link DataFormat}
      * and sets the output on the out message body.
      *
@@ -1586,6 +1593,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/data-format.html">DataFormat:</a>
      * Unmarshals the in body using the specified {@link DataFormat}
      * and sets the output on the out message body.
      *
@@ -1597,6 +1605,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/data-format.html">DataFormat:</a>
      * Unmarshals the in body using the specified {@link DataFormat}
      * reference in the {@link org.apache.camel.spi.Registry} and sets
      * the output on the out message body.
@@ -1610,6 +1619,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/data-format.html">DataFormat:</a>
      * Marshals the in body using a {@link DataFormat} expression to define
      * the format of the output which will be added to the out body.
      *
@@ -1620,6 +1630,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/data-format.html">DataFormat:</a>
      * Marshals the in body using the specified {@link DataFormat}
      * and sets the output on the out message body.
      *
@@ -1632,6 +1643,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/data-format.html">DataFormat:</a>
      * Marshals the in body using the specified {@link DataFormat}
      * and sets the output on the out message body.
      *
@@ -1643,6 +1655,7 @@
     }
 
     /**
+     * <a href="http://activemq.apache.org/camel/data-format.html">DataFormat:</a>
      * Marshals the in body the specified {@link DataFormat}
      * reference in the {@link org.apache.camel.spi.Registry} and sets
      * the output on the out message body.
@@ -1859,7 +1872,6 @@
      * behaviour
      */
     protected Processor createCompositeProcessor(RouteContext routeContext, List<Processor> list) {
-        // return new MulticastProcessor(list);
         return new Pipeline(list);
     }
 

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesType.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesType.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesType.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesType.java Tue Nov 25 12:00:24 2008
@@ -226,11 +226,11 @@
     /**
      * Adds an on exception
      * 
-     * @param exceptionType  the exception
+     * @param exception  the exception
      * @return the builder
      */
-    public ExceptionType onException(Class exceptionType) {
-        ExceptionType answer = new ExceptionType(exceptionType);
+    public ExceptionType onException(Class exception) {
+        ExceptionType answer = new ExceptionType(exception);
         getExceptions().add(answer);
         return answer;
     }

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Delayer.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Delayer.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Delayer.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/processor/Delayer.java Tue Nov 25 12:00:24 2008
@@ -87,8 +87,6 @@
     /**
      * A Strategy Method to allow derived implementations to decide the current
      * system time or some other default exchange property
-     * 
-     * @param exchange
      */
     protected long defaultProcessTime(Exchange exchange) {
         return currentSystemTime();
--- activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/BuilderSupport.java (original)
+++ activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/BuilderSupport.java Tue Nov 25 12:00:24 2008
@@ -108,8 +108,7 @@
     public <T> ValueBuilder faultBodyAs(Class<T> type) {
         return Builder.faultBodyAs(type);
     }
-
-
+                             
     /**
      * Returns a value builder for the given system property
      */
@@ -132,9 +131,34 @@
     }
 
     /**
+     * Returns a <a href="http://activemq.apache.org/camel/bean-language.html">bean expression</a>
+     * value builder
+     *
+     * @param beanRef  reference to bean to lookup in the Registry
+     * @return the builder
+     */
+    public ValueBuilder bean(String beanRef) {
+        return Builder.bean(beanRef, null);
+    }
+
+    /**
+     * Returns a <a href="http://activemq.apache.org/camel/bean-language.html">bean expression</a>
+     * value builder
+     *
+     * @param beanRef  reference to bean to lookup in the Registry
+     * @param method   name of method to invoke
+     * @return the builder
+     */
+    public ValueBuilder bean(String beanRef, String method) {
+        return Builder.bean(beanRef, method);
+    }
+
+    /**
      * Resolves the given URI to an endpoint
      *
+     * @param uri  the uri to resolve
      * @throws NoSuchEndpointException if the endpoint URI could not be resolved
+     * @return the endpoint
      */
     public Endpoint endpoint(String uri) throws NoSuchEndpointException {
         ObjectHelper.notNull(uri, "uri");
@@ -148,7 +172,10 @@
     /**
      * Resolves the given URI to an endpoint of the specified type
      *
+     * @param uri  the uri to resolve
+     * @param type the excepted type of the endpoint
      * @throws NoSuchEndpointException if the endpoint URI could not be resolved
+     * @return the endpoint
      */
     public <T extends Endpoint> T endpoint(String uri, Class<T> type) throws NoSuchEndpointException {
         ObjectHelper.notNull(uri, "uri");
@@ -162,7 +189,9 @@
     /**
      * Resolves the list of URIs into a list of {@link Endpoint} instances
      *
+     * @param uris  list of endpoints to resolve
      * @throws NoSuchEndpointException if an endpoint URI could not be resolved
+     * @return list of endpoints
      */
     public List<Endpoint> endpoints(String... uris) throws NoSuchEndpointException {
         List<Endpoint> endpoints = new ArrayList<Endpoint>();
@@ -174,6 +203,9 @@
 
     /**
      * Helper method to create a list of {@link Endpoint} instances
+     *
+     * @param endpoints  endpoints
+     * @return list of the given endpoints
      */
     public List<Endpoint> endpoints(Endpoint... endpoints) {
         List<Endpoint> answer = new ArrayList<Endpoint>();
@@ -182,48 +214,83 @@
     }
 
     /**
      * Creates a disabled error handler for removing the default error handler
      */
     public NoErrorHandlerBuilder noErrorHandler() {
         return new NoErrorHandlerBuilder();
     }
 
     /**
      * Creates an error handler which just logs errors
      */
     public LoggingErrorHandlerBuilder loggingErrorHandler() {
         return new LoggingErrorHandlerBuilder();
     }
 
     /**
      * Creates an error handler which just logs errors
      */
     public LoggingErrorHandlerBuilder loggingErrorHandler(String log) {
         return loggingErrorHandler(LogFactory.getLog(log));
     }
 
     /**
      * Creates an error handler which just logs errors
      */
     public LoggingErrorHandlerBuilder loggingErrorHandler(Log log) {
         return new LoggingErrorHandlerBuilder(log);
     }
 
     /**
      * Creates an error handler which just logs errors
      */
     public LoggingErrorHandlerBuilder loggingErrorHandler(Log log, LoggingLevel level) {
         return new LoggingErrorHandlerBuilder(log, level);
     }
 
+    /**
+     * <a href="http://activemq.apache.org/camel/dead-letter-channel.html">Dead Letter Channel EIP:</a>
+     * is a error handler for handling messages that could not be delivered to it's intented destination.
+     *
+     * @return the builder
+     */
     public DeadLetterChannelBuilder deadLetterChannel() {
         return new DeadLetterChannelBuilder();
     }
 
+    /**
+     * <a href="http://activemq.apache.org/camel/dead-letter-channel.html">Dead Letter Channel EIP:</a>
+     * is a error handler for handling messages that could not be delivered to it's intented destination.
+     *
+     * @param deadLetterUri  uri to the dead letter endpoint storing dead messages
+     * @return the builder
+     */
     public DeadLetterChannelBuilder deadLetterChannel(String deadLetterUri) {
         return deadLetterChannel(endpoint(deadLetterUri));
     }
 
+    /**
+     * <a href="http://activemq.apache.org/camel/dead-letter-channel.html">Dead Letter Channel EIP:</a>
+     * is a error handler for handling messages that could not be delivered to it's intented destination.
+     *
+     * @param deadLetterEndpoint  dead letter endpoint storing dead messages
+     * @return the builder
+     */
     public DeadLetterChannelBuilder deadLetterChannel(Endpoint deadLetterEndpoint) {
         return new DeadLetterChannelBuilder(new SendProcessor(deadLetterEndpoint));
     }
@@ -182,48 +214,83 @@
 
     /**
-     * Creates a disabled error handler for removing the default error handler
+     * Creates a disabled <a href="http://activemq.apache.org/camel/error-handler.html">error handler</a>
+     * for removing the default error handler
+     *
+     * @return the builder
      */
     public NoErrorHandlerBuilder noErrorHandler() {
@@ -182,48 +214,83 @@
 
     /**
-     * Creates an error handler which just logs errors
+     * Creates an <a href="http://activemq.apache.org/camel/error-handler.html">error handler</a>
+     * which just logs errors
+     *
+     * @return the builder
      */
     public LoggingErrorHandlerBuilder loggingErrorHandler() {
@@ -182,48 +214,83 @@
 
     /**
-     * Creates an error handler which just logs errors
+     * Creates an <a href="http://activemq.apache.org/camel/error-handler.html">error handler</a>
+     * which just logs errors
+     *
+     * @return the builder
      */
     public LoggingErrorHandlerBuilder loggingErrorHandler(String log) {
@@ -182,48 +214,83 @@
 
     /**
-     * Creates an error handler which just logs errors
+     * Creates an <a href="http://activemq.apache.org/camel/error-handler.html">error handler</a>
+     * which just logs errors
+     *
+     * @return the builder
      */
     public LoggingErrorHandlerBuilder loggingErrorHandler(Log log) {
@@ -182,48 +214,83 @@
 
     /**
-     * Creates an error handler which just logs errors
+     * Creates an <a href="http://activemq.apache.org/camel/error-handler.html">error handler</a>
+     * which just logs errors
+     *
+     * @return the builder
      */
     public LoggingErrorHandlerBuilder loggingErrorHandler(Log log, LoggingLevel level) {

Modified: activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/ExpressionBuilder.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/camel-core/src/main/java/org/apache/camel/builder/ExpressionBuilder.java?rev=720581&r1=720580&r2=720581&view=diff
==============================================================================